.send_request: Sends a request to the specified url and retrieves it's content.
Description
Sends a request to the specified url and retrieves it's content.
Usage
.send_request(request_url, apikey, query = NULL)
Arguments
query
Default value is NULL. Optional argument if you want to add query to request
Value
parsed content of the response object