Learn R Programming

aiRly (version 0.1.0)

get_indexes: Get Airly available indexes

Description

Endpoint returns a list of all the index types supported in the API along with lists of levels defined per each index type.

Usage

get_indexes()

Arguments

Value

object of airly_meta class

Examples

Run this code
# NOT RUN {
 get_indexes()
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab