Learn R Programming

aiRly (version 0.1.0)

get_installation_measurements: Get Airly measurements for any geographical location given installation id

Description

Endpoint returns measurements for concrete installation given by installation Id

Usage

get_installation_measurements(id)

Arguments

id

integer, installation identifier

Value

object of airly_measurements class

Examples

Run this code
# NOT RUN {
 get_installation_measurements(8077)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab