Learn R Programming

aiRly (version 0.1.0)

get_nearest_measurements: Get Airly nearest measurements to given point

Description

Endpoint returns measurements for an installation closest to a given location

Usage

get_nearest_measurements(lat, lng, max_distance = NULL)

Arguments

lat

latitude as decimal degree

lng

longitude as decimal degree

max_distance

default value 3.0. All the returned installations must be located within this limit from the given point (in km). Negative value means no limit

Value

data.frame of airly_measurements items

Examples

Run this code
# NOT RUN {
get_nearest_measurements(50.11670, 19.91429, max_distance = 10)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab