Learn R Programming

aiRly (version 0.1.0)

is_airly_api_response: Checks whether the given object is of the class airly_api_response

Description

Checks whether the given object is of the class airly_api_response

Usage

is_airly_api_response(x)

Arguments

x

object to test if it is of the class airly_api_response

Value

TRUE if the object is of the class airly_api_response