Learn R Programming

aiRly (version 0.1.0)

is_airly_measurement: Checks whether the given object is of the class airly_measurement

Description

Checks whether the given object is of the class airly_measurement

Usage

is_airly_measurement(x)

Arguments

x

object to test if it is of the class airly_measurement

Value

TRUE if the object is of the class airly_measurement