powered by
Endpoint returns a list of all the index types supported in the API along with lists of levels defined per each index type.
get_indexes()
object of airly_meta class
# NOT RUN { get_indexes() # } # NOT RUN { # }
Run the code above in your browser using DataLab