powered by
Endpoint returns measurements for an installation closest to a given location
get_nearest_measurements(lat, lng, max_distance = NULL)
latitude as decimal degree
longitude as decimal degree
default value 3.0. All the returned installations must be located within this limit from the given point (in km). Negative value means no limit
data.frame of airly_measurements items
# NOT RUN { get_nearest_measurements(50.11670, 19.91429, max_distance = 10) # } # NOT RUN { # }
Run the code above in your browser using DataLab