powered by
Checks whether the given object is of the class airly_measurement
is_airly_measurement(x)
object to test if it is of the class airly_measurement
TRUE if the object is of the class airly_measurement